@@ -1,7 +1,7 @@
 ### FUNCTION TO DRAW CIRCLE (IN FACT A POLYGON) ###################################################
 circle <- function(x, y, r, gp = NULL) {
 	
-	poly <- ell2poly(x, y, r, r, 0, 3000);
+	poly <- VennDiagram::ell2poly(x, y, r, r, 0, 3000);
 	
 	return(
 		polygonGrob(
